<?php

namespace Ardent\PipelineBundle\Pipeline\OptionsProcessor;

class Item
{
    private string|int $id;

    private bool $delete = false;

    private ?ItemCollection $children = null;
    private ?Item $parent = null;

    private array $data = [];

    public function __construct(
        string|int|null        $id = null
    )
    {
        $id ??= sha1(microtime());
        $this->id = $id;
    }

    public function getId(): string
    {
        return $this->id;
    }

    public function isDelete(): bool
    {
        return $this->delete;
    }

    public function setDelete(): void
    {
        $this->delete = true;
    }

    // Data manipulation
    public function get(string $key, mixed $default = null): mixed
    {
        return $this->has($key) ? $this->data[$key] : $default;
    }

    public function set(string $key, mixed $value): self
    {
        $this->data[$key] = $value;

        return $this;
    }

    public function has(string $key): bool
    {
        return array_key_exists($key, $this->data);
    }

    public function getChildren(): ?ItemCollection
    {
        return $this->children;
    }

    public function setChildren(ItemCollection $children): void
    {
        $this->children = $children;
    }

    public function addChild(Item $item): self
    {
        if (!$this->children) {
            $this->children = new ItemCollection();
        }
        $item->setParent($this);
        $this->children->add($item);

        return $this;
    }

    public function getParent(): ?Item
    {
        return $this->parent;
    }

    public function setParent(?Item $parent): Item
    {
        $this->parent = $parent;
        return $this;
    }
}