<?php

namespace Ardent\PipelineBundle\Pipeline\OptionsProcessor;

use Psr\Log\LoggerInterface;

class ItemsOptionsPipeline
{
    /**
     * @var OptionsStageInterface[]
     */
    private array $stages;

    public function __construct(
        private readonly OptionsProcessor $processor,
        OptionsStageInterface             ...$stages)
    {
        $this->stages = $stages;
    }

    public function setLogger(LoggerInterface $logger): void
    {
        foreach ($this->stages as $stage) {
            $stage->setLogger($logger);
        }
    }

    /**
     * @param Item[]|ItemCollection $items
     */
    public function process(array|ItemCollection $items): ItemCollection
    {
        if (is_array($items)) {
            $itemBag = new ItemCollection();
            foreach ($items as $item) {
                $itemBag->add($item);
            }
        } else {
            $itemBag = $items;
        }
        return $this->processor->process($itemBag, ...$this->stages);
    }
}